use std::path::Path;

use log::info;

use ambient_driver::{action::ActionRunnerBuilder, config::RunCiConfig, plan::Plan, qemu};

const PLAN_FILENAME: &str = "plan.yaml";
const RUN_CI_CONFIG_FILENAME: &str = "config.yaml";

fn main() -> anyhow::Result<()> {
    pretty_env_logger::init();
    println!("run-ci starts");
    info!("xyzzy, via log");
    println!("xyzzy, via println");
    let config = RunCiConfig::from_file(Path::new(RUN_CI_CONFIG_FILENAME))?;
    println!("run-ci: config from file={config:#?}");
    let plan = Plan::from_file(Path::new(PLAN_FILENAME))?;
    println!("run-ci: plan from file={plan:#?}");
    let runner = ActionRunnerBuilder::default()
        .source(Path::new(qemu::SOURCE_DIR))
        .dependencies(Path::new(qemu::DEPS_DIR))
        .artifacts(Path::new(qemu::ARTIFACTS_DIR))
        .build()?;
    for action in plan.iter() {
        println!("RUN: {:#?}", action);
        runner.execute(&config, action)?;
    }
    println!("run-ci ends");
    Ok(())
}
